==> dde-session-shell_5.5.34.tar.xz: BUILD/translations/dde-session-shell_mr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="mr" version="2.1">
<context>
    <name>ContentWidget</name>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="315"/>
        <source>The programs are preventing the computer from shutting down / hibernation, and forcing shut down / hibernate may cause data loss.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="316"/>
        <source>To close the program, click Cancel, and then close the program.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="328"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="365"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="387"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="521"/>
        <source>Shut down</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="330"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="367"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="390"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="524"/>
        <source>Reboot</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="332"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="527"/>
        <source>Suspend</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="334"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="530"/>
        <source>Hibernate</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="336"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="393"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="536"/>
        <source>Log out</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="388"/>
        <source>Are you sure you want to shut down?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="391"/>
        <source>Are you sure you want to reboot?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="394"/>
        <source>Are you sure you want to log out?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="533"/>
        <source>Lock</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="540"/>
        <source>Switch user</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>GreeterWorkek</name>
    <message>
        <location filename="../src/lightdm-deepin-greeter/greeterworkek.cpp" line="94"/>
        <source>Domain account</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/lightdm-deepin-greeter/greeterworkek.cpp" line="288"/>
        <source>Wrong Password</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/lightdm-deepin-greeter/greeterworkek.cpp" line="293"/>
        <source>The domain account or password is not correct. Please enter again.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>InhibitWarnView</name>
    <message>
        <location filename="../src/dde-shutdown/view/inhibitwarnview.cpp" line="88"/>
        <source>Cancel</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>LockWorker</name>
    <message>
        <location filename="../src/dde-lock/lockworker.cpp" line="92"/>
        <source>Domain account</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/dde-lock/lockworker.cpp" line="211"/>
        <source>Fingerprint verification timed out, please enter your password manually</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/dde-lock/lockworker.cpp" line="229"/>
        <source>Failed to match fingerprint</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/dde-lock/lockworker.cpp" line="264"/>
        <source>Wrong Password</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MultiUsersWarningView</name>
    <message>
        <location filename="../src/dde-shutdown/view/multiuserswarningview.cpp" line="45"/>
        <source>Cancel</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/multiuserswarningview.cpp" line="126"/>
        <source>The above users are still logged in and data will be lost due to shutdown, are you sure you want to shut down?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/multiuserswarningview.cpp" line="130"/>
        <source>The above users are still logged in and data will be lost due to reboot, are you sure you want to reboot?</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ShutdownWidget</name>
    <message>
        <location filename="../src/session-widgets/userinputwidget.cpp" line="285"/>
        <location filename="../src/widgets/shutdownwidget.cpp" line="29"/>
        <source>Shut down</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/session-widgets/userinputwidget.cpp" line="301"/>
        <source>Log in</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/session-widgets/userinputwidget.cpp" line="310"/>
        <location filename="../src/widgets/shutdownwidget.cpp" line="30"/>
        <location filename="../src/widgets/shutdownwidget.cpp" line="101"/>
        <source>Reboot</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/widgets/shutdownwidget.cpp" line="31"/>
        <location filename="../src/widgets/shutdownwidget.cpp" line="108"/>
        <source>Suspend</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/widgets/shutdownwidget.cpp" line="32"/>
        <location filename="../src/widgets/shutdownwidget.cpp" line="115"/>
        <source>Hibernate</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SystemMonitor</name>
    <message>
        <location filename="../src/dde-shutdown/view/systemmonitor.cpp" line="45"/>
        <source>Start system monitor</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>TimeWidget</name>
    <message>
        <location filename="../src/widgets/timewidget.cpp" line="82"/>
        <source>hh:mm</source>
        <translation>hh:mm</translation>
    </message>
    <message>
        <location filename="../src/widgets/timewidget.cpp" line="84"/>
        <source>hh:mm ap</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/widgets/timewidget.cpp" line="87"/>
        <source>yyyy-MM-dd dddd</source>
        <translation>yyyy-MM-dd dddd</translation>
    </message>
</context>
<context>
    <name>UserInputWidget</name>
    <message>
        <location filename="../src/session-widgets/userinputwidget.cpp" line="13"/>
        <source>Log in</source>
        <translation type="unfinished"/>
    </message>
    <message numerus="yes">
        <location filename="../src/session-widgets/userinputwidget.cpp" line="257"/>
        <source>Please try again %n minute(s) later</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>UserLoginWidget</name>
    <message numerus="yes">
        <location filename="../src/session-widgets/userloginwidget.cpp" line="235"/>
        <source>Please try again %n minute(s) later</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
</context>
</TS>

==> dde-session-shell_6.0.21.tar.xz: BUILD/translations/dde-session-shell_mr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="mr">
<context>
    <name>AuthFace</name>
    <message>
        <source>Face ID</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Verification successful</source>
        <translation type="unfinished"/>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Verify your Face ID</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Face ID locked, use password please</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Device unavailable!</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AuthFingerprint</name>
    <message>
        <source>Verify your fingerprint</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Verification successful</source>
        <translation type="unfinished"/>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Fingerprint locked, use password please</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AuthIris</name>
    <message>
        <source>Iris ID</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Verification successful</source>
        <translation type="unfinished"/>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Verify your Iris ID</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Iris ID locked, use password please</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AuthPassword</name>
    <message>
        <source>Verification successful</source>
        <translation type="unfinished"/>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Password</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation type="unfinished"/>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Reset Password</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Forgot password?</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AuthSingle</name>
    <message>
        <source>Please try again 1 minute later</source>
        <translation type="unfinished"/>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Reset Password</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Forgot password?</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AuthUKey</name>
    <message>
        <source>Verification successful</source>
        <translation type="unfinished"/>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Wrong PIN</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>UKey is required</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Enter your PIN</source>
        <translation type="unfinished"/>
    </message>
    <message numerus="yes">
        <source>Please try again %n minute(s) later</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation type="unfinished"/>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>AuthWidget</name>
    <message>
        <source>Account</source>
        <translation type="unfinished"/>
    </message>
    <message numerus="yes">
        <source>Your password will expire in %n days, please change it timely</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Your password has expired. Please contact the administrator to change it.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Your password has expired. Please change it.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ChangePasswordWidget</name>
    <message>
        <source>Your password has expired. Please change it and log in again.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Save</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Old password</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>New password</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Repeat new password</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Password hint (Optional)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Passwords do not match</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The hint is visible to all users. Do not include the password here.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>New password should differ from the current one</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Password changed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Wrong password</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ControlWidget</name>
    <message>
        <source>Desktop Environment and Display Protocol</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Keyboard Layout</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Switch User</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Power</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>GreeterWorker</name>
    <message>
        <source>Wrong account</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>InhibitWarnView</name>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>LockContent</name>
    <message>
        <source>Lock Screen</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to lock screen</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>LockWorker</name>
    <message>
        <source>Fingerprint verification timed out, please enter your password manually</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to match fingerprint</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MultiUsersWarningView</name>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to shutdown, are you sure you want to shut down?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to reboot, are you sure you want to reboot?</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>PasswordLevelWidget</name>
    <message>
        <source>Weak</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Medium</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Strong</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>PwqualityManager</name>
    <message>
        <source>Password cannot be empty</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Password must have at least %1 characters</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Password must be no more than %1 characters</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Password can only contain English letters (case-sensitive), numbers or special symbols (~`!@#$%^&amp;*()-_+=|\{}[]:&quot;&apos;&lt;&gt;,.?/)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>No more than %1 palindrome characters please</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>No more than %1 monotonic characters please</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>No more than %1 repeating characters please</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Password must contain uppercase letters, lowercase letters, numbers and symbols (~`!@#$%^&amp;*()-_+=|\{}[]:&quot;&apos;&lt;&gt;,.?/)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Password must not contain more than 4 palindrome characters</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Do not use common words and combinations as password</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Create a strong password please</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>It does not meet password rules</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ShutdownWidget</name>
    <message>
        <source>Shut down</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Reboot</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Suspend</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Hibernate</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Lock</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Log out</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Switch system</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Switch user</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SystemMonitor</name>
    <message>
        <source>Start system monitor</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UserListPopupWidget</name>
    <message>
        <source>Standard User</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Administrator</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Other Users</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>VirtualKeyboardModule</name>
    <message>
        <source>Onboard</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>WarningContent</name>
    <message>
        <source>The programs are preventing the computer from shutting down, and forcing shut down may cause data loss.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>To close the program, click Cancel, and then close the program.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The programs are preventing the computer from reboot, and forcing reboot may cause data loss.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The programs are preventing the computer from suspend, and forcing suspend may cause data loss.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The programs are preventing the computer from hibernate, and forcing hibernate may cause data loss.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The programs are preventing the computer from log out, and forcing log out may cause data loss.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Shut down</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Reboot</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Suspend</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Hibernate</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Log out</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Are you sure you want to shut down?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Are you sure you want to reboot?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Are you sure you want to log out?</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>dss::module::NetworkModule</name>
    <message>
        <source>Turn on</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Turn off</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
